import 'package:unittest/unittest.dart';
import 'package:japanese_util/japanese_util.dart';

void main() {
  test("Japanese Iterator", () {
    const testString = "𩸽のお寿司🍣"; // must includes some surrogate pairs(e.g. emojis).
    const testStringList = const <String>["𩸽", "の", "お", "寿", "司", "🍣"];

    var iterator = new JapaneseIterator(testString);
    var output   = new List<String>();

    for(;iterator.moveNext();) {
      output.add(iterator.current);
    }

    expect(output, orderedEquals(testStringList));
  });

  // It seems to me that we don't need to test Iterable<String>'s methods,
  // since JapaneseString is a derived class of IterableBase<String>
  // which implements almost methods and should have been well-tested.
  group("Japanese String", () {

    // These texts should include every hiraganas or katakanas.
    // High character coverage may improve quality of tests.
    var hiraganaText = "いろはにほへとちりぬるをわかよたれそつねならむ" +
                       "うゐのおくやまけふこえてあさきゆめみしゑひもせすん" +
                       "がぎぐげござじずぜぞだぢづでどゔぱぴぷぺぽ" +
                       "ぁぃぅぇぉっゃゅょゎ";
    var katakanaText = "イロハニホヘトチリヌルヲワカヨタレソツネナラム" +
                       "ウヰノオクヤマケフコエテアサキユメミシヱヒモセスン" +
                       "ガギグゲゴザジズゼゾダヂヅデドヴパピプペポ" +
                       "ァィゥェォッャュョヮ";

    test('hiraganize', () => expect(hiraganize(katakanaText), equals(hiraganaText)));
    test('katakanize', () => expect(katakanize(hiraganaText), equals(katakanaText)));
  });
}